@@ -51,9 +51,13 @@ def entrypoint(args):
     pr.create_review_request(github_reviewers)
     logger.info('Aggiungo reviewers su GitHub')
 
+    revs = ""
     for rev in slack_reviewers:
-        slack.post('#review', '<@{}> {}'.format(
-            rev, pr.html_url))
+        revs += "<@{}> ".format(rev)
+
+    slack.post('#review', '{}{}'.format(
+        revs, pr.html_url))
+
     logger.info('Cito reviewers su Slack')
 
     youtrack_id = youtrack.get_card_from_name(pr.title)
