@@ -6,7 +6,6 @@ from ..lib.handler import prompt_utils
 from ..lib.logger import Logger
 from ..lib.config import Config
 import sys
-import os
 import semver
 
 youtrack = YoutrackHandler()
@@ -17,16 +16,12 @@ slack = SlackHandler()
 
 
 def entrypoint(args):
-    project = os.path.basename(os.getcwd())
-    if not prompt_utils.ask_confirm("Vuoi continuare sul progetto {}?".format(project)):
-        sys.exit(-1)
-
     if prompt_utils.ask_confirm("Sono presenti migration?", default=False):
         logger.error(
             "Impossibile continuare con il deploy a causa di migration presenti. Chiedi ai devops di effettuare il deploy.")
         sys.exit(-1)
 
-    repo = github.get_repo(project)
+    repo = github.get_repo(args.project)
 
     latest_release = get_release(repo)
 
@@ -63,7 +58,7 @@ def entrypoint(args):
     except:
         logger.warning("Si è verificato un errore durante lo spostamento delle card in {}".format(release_state))
     finally:
-        create_release(repo, new_version, message, project, deployed_cards_link)
+        create_release(repo, new_version, message, args.project, deployed_cards_link)
 
 
 def get_release(repo):
